import React from 'react';
import { Link } from 'react-router-dom';
import SvgIcon from '../../../components/SvgIcon';

// Custom styled Link component with hover effect
const StyledLink = ({ to, children }) => {
    return (
        <Link
            to={to}
            className='text-secondary text-decoration-none'
            style={{ transition: 'all 0.2s ease' }}
            onMouseOver={(e) => (e.currentTarget.style.color = '#212529')}
            onMouseOut={(e) => (e.currentTarget.style.color = '')}
        >
            {children}
        </Link>
    );
};

export default function SettingsTab({ knowledgeBase }) {
    // Handle form submission
    const handleSubmit = (e) => {
        e.preventDefault();
        // Here you would typically call an API to update the knowledge base settings
        console.log('Updating knowledge base settings');
    };

    // Handle knowledge base deletion
    const handleDelete = () => {
        // Here you would typically call an API to delete the knowledge base
        console.log('Deleting knowledge base:', knowledgeBase.id);
    };

    return (
        <>
            {/* Breadcrumb navigation */}
            <div className='d-flex align-items-center mb-4 mt-3'>
                <nav aria-label='breadcrumb'>
                    <ol className='breadcrumb mb-0'>
                        <li className='breadcrumb-item'>
                            <StyledLink to='/'>知识库</StyledLink>
                        </li>
                        <li className='breadcrumb-item'>
                            <StyledLink to={`/knowledge-base/${knowledgeBase.id}`}>{knowledgeBase.title}</StyledLink>
                        </li>
                        <li className='breadcrumb-item active text-secondary' aria-current='page'>
                            设置
                        </li>
                    </ol>
                </nav>
            </div>

            {/* Settings form */}
            <div className='card border-0 shadow-sm'>
                <div className='card-body'>
                    <h5 className='card-title mb-4'>知识库设置</h5>

                    <form onSubmit={handleSubmit}>
                        <div className='mb-3'>
                            <label htmlFor='knowledgeTitle' className='form-label'>
                                知识库名称
                            </label>
                            <input
                                type='text'
                                className='form-control'
                                id='knowledgeTitle'
                                defaultValue={knowledgeBase.title}
                            />
                        </div>

                        <div className='mb-3'>
                            <label htmlFor='knowledgeDescription' className='form-label'>
                                知识库描述
                            </label>
                            <textarea
                                className='form-control'
                                id='knowledgeDescription'
                                rows='3'
                                defaultValue={knowledgeBase.description}
                            ></textarea>
                        </div>

                        <div className='mb-3'>
                            <label className='form-label'>访问权限</label>
                            <div className='form-check'>
                                <input
                                    className='form-check-input'
                                    type='radio'
                                    name='accessPermission'
                                    id='accessPublic'
                                    defaultChecked
                                />
                                <label className='form-check-label' htmlFor='accessPublic'>
                                    公开 - 所有人可访问
                                </label>
                            </div>
                            <div className='form-check'>
                                <input
                                    className='form-check-input'
                                    type='radio'
                                    name='accessPermission'
                                    id='accessPrivate'
                                />
                                <label className='form-check-label' htmlFor='accessPrivate'>
                                    私有 - 仅创建者可访问
                                </label>
                            </div>
                        </div>

                        <div className='mb-3'>
                            <label className='form-label'>权限管理</label>
                            <div className='card'>
                                <div className='card-body p-0'>
                                    <table className='table mb-0'>
                                        <thead className='table-light'>
                                            <tr>
                                                <th scope='col'>ID</th>
                                                <th scope='col'>用户名</th>
                                                <th scope='col'>邮箱</th>
                                                <th scope='col'>权限类型</th>
                                                <th scope='col'>访问时长</th>
                                                <th scope='col'>操作</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <tr>
                                                <td>#1001</td>
                                                <td>测试数据集 001</td>
                                                <td>zhang@abc.com</td>
                                                <td>只读</td>
                                                <td>一个月</td>
                                                <td>
                                                    <div className='d-flex gap-2'>
                                                        <button
                                                            className='btn btn-sm btn-outline-secondary'
                                                            title='编辑'
                                                        >
                                                            <SvgIcon className='edit' />
                                                        </button>
                                                        <button className='btn btn-sm btn-outline-danger' title='删除'>
                                                            <SvgIcon className='trash' />
                                                        </button>
                                                    </div>
                                                </td>
                                            </tr>
                                            <tr>
                                                <td>#1002</td>
                                                <td>产品分析数据</td>
                                                <td>li@abc.com</td>
                                                <td>完全访问</td>
                                                <td>永久</td>
                                                <td>
                                                    <div className='d-flex gap-2'>
                                                        <button
                                                            className='btn btn-sm btn-outline-secondary'
                                                            title='编辑'
                                                        >
                                                            <SvgIcon className='edit' />
                                                        </button>
                                                        <button className='btn btn-sm btn-outline-danger' title='删除'>
                                                            <SvgIcon className='trash' />
                                                        </button>
                                                    </div>
                                                </td>
                                            </tr>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <button type='button' className='btn btn-outline-primary mt-2'>
                                <SvgIcon className='plus me-1' />
                                添加用户
                            </button>
                        </div>

                        <div className='d-flex justify-content-end gap-2 mt-4'>
                            <button type='button' className='btn btn-outline-danger' onClick={handleDelete}>
                                删除知识库
                            </button>
                            <button type='submit' className='btn btn-primary'>
                                保存设置
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </>
    );
}
